==> 1Password-3.4.2.zip: 1Password.app/Contents/Resources/Accounts/Email.opaccountitem/Definition.js <==
{
	"class":"wallet.onlineservices.Email",
	"localized":"yes",
	"contents":[
		{
			"set":"",
			"disclosed":"yes",
			"fields":[
				{ "name":"pop_type", "type":"menu", "menuitems":["pop3", "imap", "either"] },
				{ "name":"pop_username", "type":"string" },
				{ "name":"pop_server", "type":"string" },
				{ "name":"pop_port", "type":"string", "width":"60" },

				{ "name":"pop_password", "type":"concealed" },
				{ "name":"pop_use_ssl", "type":"menu", "menuitems":["yes", "no"] },
				{ "name":"pop_authentication", "type":"menu", "menuitems":["none", "password", "md5_challenge_response", "kerberized_pop", "kerberos_v4", "kerberos_v5", "ntlm"] }
			]
		},
		
		{
			"set":"SMTP",
			"disclosed":"yes",
			"fields":[
				{ "name":"smtp_server", "type":"string" },
				{ "name":"smtp_port", "type":"string", "width":"60" },
				{ "name":"smtp_username", "type":"string" },
				{ "name":"smtp_password", "type":"concealed" },
				{ "name":"smtp_use_ssl", "type":"menu", "menuitems":["yes", "no"] },
				{ "name":"smtp_authentication", "type":"menu", "menuitems":["none", "password", "md5_challenge_response", "kerberized_pop", "kerberos_v4", "kerberos_v5", "ntlm"] }
			]
		},
		
		{
			"set":"Contact Information",
			"disclosed":"no",
			"fields": [
				{ "name":"provider", "type":"string" },
				{ "name":"provider_website", "type":"string" },
				{ "name":"phone_local", "type":"string", "subtype":"phone" },
				{ "name":"phone_tollfree", "type":"string", "subtype":"phone" }
			]
		}
	]
}

==> 1Password-3.6.5.zip: 1Password.app/Contents/Resources/Accounts/Email.opaccountitem/Definition.js <==
{
	"class":"wallet.onlineservices.Email",
	"localized":"yes",
	"deprecated":"yes",	
	"contents":[
		{
			"set":"",
			"disclosed":"yes",
			"fields":[
				{ "name":"pop_type", "type":"menu", "menuitems":["pop3", "imap", "either"] },
				{ "name":"pop_username", "type":"string", "isUsername":"yes" },
				{ "name":"pop_server", "type":"string" },
				{ "name":"pop_port", "type":"string", "width":"60" },

				{ "name":"pop_password", "type":"concealed" },
				{ "name":"pop_use_ssl", "type":"menu", "menuitems":["yes", "no"] },
				{ "name":"pop_authentication", "type":"menu", "menuitems":["none", "password", "md5_challenge_response", "kerberized_pop", "kerberos_v4", "kerberos_v5", "ntlm"] }
			]
		},
		
		{
			"set":"SMTP",
			"disclosed":"yes",
			"fields":[
				{ "name":"smtp_server", "type":"string" },
				{ "name":"smtp_port", "type":"string", "width":"60" },
				{ "name":"smtp_username", "type":"string", "isUsername":"yes" },
				{ "name":"smtp_password", "type":"concealed" },
				{ "name":"smtp_use_ssl", "type":"menu", "menuitems":["yes", "no"] },
				{ "name":"smtp_authentication", "type":"menu", "menuitems":["none", "password", "md5_challenge_response", "kerberized_pop", "kerberos_v4", "kerberos_v5", "ntlm"] }
			]
		},
		
		{
			"set":"Contact Information",
			"disclosed":"no",
			"fields": [
				{ "name":"provider", "type":"string" },
				{ "name":"provider_website", "type":"string" },
				{ "name":"phone_local", "type":"string", "subtype":"phone" },
				{ "name":"phone_tollfree", "type":"string", "subtype":"phone" }
			]
		}
	]
}
